---
title: "Slack usage guidelines"
linkTitle: "Slack guidelines"
weight: 45
type: "docs"
---

Slack is the main communication platform for Knative outside of our mailing
lists. It’s important that conversation stays on topic in each channel, and that
everyone abides by the Code of Conduct. Community members should all expect to
have a positive experience.

Chat is searchable and public. Do not make comments that you would not say on a
video recording or in another public space. Please be courteous to others.

`@here` and `@channel` should be used rarely. Members will receive notifications
from these commands and we are a global project - please be kind. Note: `@all`
is only to be used by admins.

You can join the [Knative Slack](https://slack.knative.dev) instance at
https://slack.knative.dev.

## Code of Conduct

The Knative [Code of Conduct](./CODE-OF-CONDUCT.md) applies throughout the
project, and includes all communication mediums.

## Admins

- @mchmarny
- @isdal
- @dewitt

Slack admins should make sure to mention this in the “What I do” section of
their Slack profile, as well as for which time zone.

To connect: please reach out in the #slack-admins channel, mention one of us in
the specific channel where you have a question, or DM (Direct Message) one of us
privately.

### Admin Expectations and Guidelines

- Adhere to Code of Conduct
- Take care of spam as soon as possible, which may mean taking action by making
  members inactive
- Moderating and fostering a safe environment for conversations
- Bring Code of Conduct issues to the Steering Committee
- Create relevant channels and list Code of Conduct in new channel welcome
  message
- Help troubleshoot Slack issues
- Review bot, token, and webhook requests
- Be helpful!

## Creating Channels

Please reach out to the #slack-admins group with your request to create a new
channel.

Channels are dedicated to [Working Groups](./WORKING-GROUPS.md), sub-projects,
community topics, and related programs/projects.

Channels are not:

- company specific; e.g. a channel named for a cloud provider must be used for
  conversation about Knative-related topics on that cloud, and not proprietary
  information of the provider.
- private unless there is an exception: code of conduct matters, mentoring,
  security/vulnerabilities, or steering committee.

All channels need a documented purpose. Use this space to welcome the targeted
community: promote your meetings, post agendas, etc.

We may make special accommodations where necessary.

## Escalating and/or Reporting a Problem

Join the #slack-admins channel or contact one of the admins in the closest
timezone via DM directly and describe the situation. If the issue can be
documented, please take a screenshot to include in your message.

### What if you have a problem with an admin

Send a DM to another listed Admin and describe the situation, or if it’s a code
of conduct issue, please send an email to
knative-code-of-conduct@googlegroups.com and describe the situation.

## Bots, Tokens, and Webhooks

Bots, tokens, and webhooks are reviewed on a case-by-case basis. Expect most
requests will be rejected due to security, privacy, and usability concerns. Bots
and the like tend to make a lot of noise in channels.

Please join #slack-admins and have a discussion about your request before
requesting the access.

## Admin Moderation

Be mindful of how you handle communication during stressful interactions.
Administrators act as direct representatives of the project, and need to
maintain a very high level of professionalism at all times. If you feel too
involved in the situation to maintain impartiality or professionalism, that’s a
great time to enlist the help of another admin.

Try to take any situations that involve upset or angry members to DM or video
chat. Please document these interactions for other Slack admins to review.

Content will be automatically removed if it violates code of conduct or is a
sales pitch. Admins will take a screenshot of such behavior in order to document
the situation. Google takes such violations extremely seriously, and they will
be handled swiftly.

## Inactivating Accounts

For reasons listed below, admins may inactivate individual Slack accounts. Due
to Slack’s framework, it does not allow for an account to be banned or suspended
in the traditional sense.
[Read Slack’s policy on this.](https://get.Slack.help/hc/en-us/articles/204475027-Deactivate-a-member-s-account)

- Spreading spam content in DMs and/or channels
- Not adhering to the code of conduct set forth in DMs and/or channels
- Overtly selling products, related or unrelated to Knative

## Specific Channel Rules

In the case that certain channels have rules or guidelines, they will be listed
in the purpose or pinned docs of that channel.

## DM (Direct Message) Conversations

Please do not engage in proprietary company specific conversations in the
Knative Slack instance. This is meant for conversations related to Knative open
source topics and community.

Proprietary conversations should occur in your company communication platforms.
As with all communication, please be mindful of appropriateness,
professionalism, and applicability to the Knative community.

---

Except as otherwise noted, the content of this page is licensed under the
[Creative Commons Attribution 4.0 License](https://creativecommons.org/licenses/by/4.0/),
and code samples are licensed under the
[Apache 2.0 License](https://www.apache.org/licenses/LICENSE-2.0).
